@@ -49,7 +49,6 @@ static gint html_a11y_table_get_row_extent_at (AtkTable *table, gint row, gint c
 static AtkObject * html_a11y_table_get_column_header (AtkTable *table, gint column);
 static AtkObject * html_a11y_table_get_row_header (AtkTable *table, gint row);
 
-
 static AtkObjectClass *parent_class = NULL;
 
 GType
@@ -104,7 +103,7 @@ atk_table_interface_init (AtkTableIface *iface)
 static void
 html_a11y_table_finalize (GObject *obj)
 {
-        G_OBJECT_CLASS (parent_class)->finalize (obj);
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
@@ -175,7 +174,7 @@ is_valid (AtkObject *table)
 		g_object_unref (ss);
 		return FALSE;
 	}
-        g_object_unref (ss);
+	g_object_unref (ss);
 
 	return TRUE;
 }
@@ -191,14 +190,13 @@ html_a11y_table_ref_at (AtkTable *table, gint row, gint column)
 	HTMLTable *to = HTML_TABLE (HTML_A11Y_HTML (table));
 	HTMLTableCell *cell;
 
-
 	if (!is_valid (ATK_OBJECT (table)))
 		return NULL;
 
 	g_return_val_if_fail (row < to->totalRows, NULL);
 	g_return_val_if_fail (column < to->totalCols, NULL);
 
-	cell = to->cells [row][column];
+	cell = to->cells[row][column];
 
 	if (cell) {
 		accessible = html_utils_get_accessible (HTML_OBJECT (cell), ATK_OBJECT (table));
@@ -219,9 +217,9 @@ html_a11y_table_get_index_at (AtkTable *table, gint row, gint column)
 
 	g_return_val_if_fail (row < to->totalRows, -1);
 	g_return_val_if_fail (column < to->totalCols, -1);
-	g_return_val_if_fail (to->cells [row][column], -1);
+	g_return_val_if_fail (to->cells[row][column], -1);
 
-	return html_object_get_child_index (HTML_OBJECT (to), HTML_OBJECT (to->cells [row][column]));
+	return html_object_get_child_index (HTML_OBJECT (to), HTML_OBJECT (to->cells[row][column]));
 }
 
 static gint
@@ -284,9 +282,9 @@ html_a11y_table_get_column_extent_at (AtkTable *table, gint row, gint column)
 
 	g_return_val_if_fail (row < to->totalRows, -1);
 	g_return_val_if_fail (column < to->totalCols, -1);
-	g_return_val_if_fail (to->cells [row][column], -1);
+	g_return_val_if_fail (to->cells[row][column], -1);
 
-	return to->cells [row][column]->cspan;
+	return to->cells[row][column]->cspan;
 }
 
 static gint
@@ -299,12 +297,11 @@ html_a11y_table_get_row_extent_at (AtkTable *table, gint row, gint column)
 
 	g_return_val_if_fail (row < to->totalRows, -1);
 	g_return_val_if_fail (column < to->totalCols, -1);
-	g_return_val_if_fail (to->cells [row][column], -1);
+	g_return_val_if_fail (to->cells[row][column], -1);
 
-	return to->cells [row][column]->rspan;
+	return to->cells[row][column]->rspan;
 }
 
-
 static AtkObject *
 html_a11y_table_get_column_header (AtkTable *table, gint column)
 {
@@ -314,10 +311,10 @@ html_a11y_table_get_column_header (AtkTable *table, gint column)
 		return NULL;
 
 	g_return_val_if_fail (column < to->totalCols, NULL);
-	g_return_val_if_fail (to->cells [0][column], NULL);
+	g_return_val_if_fail (to->cells[0][column], NULL);
 
-	return to->cells [0][column]->heading
-		? html_utils_get_accessible (HTML_OBJECT (to->cells [0][column]), ATK_OBJECT (table)) : NULL;
+	return to->cells[0][column]->heading
+		? html_utils_get_accessible (HTML_OBJECT (to->cells[0][column]), ATK_OBJECT (table)) : NULL;
 }
 
 static AtkObject *
@@ -329,21 +326,19 @@ html_a11y_table_get_row_header (AtkTable *table, gint row)
 		return NULL;
 
 	g_return_val_if_fail (row < to->totalRows, NULL);
-	g_return_val_if_fail (to->cells [row][0], NULL);
+	g_return_val_if_fail (to->cells[row][0], NULL);
 
-	return to->cells [row][0]->heading
-		? html_utils_get_accessible (HTML_OBJECT (to->cells [row][0]), ATK_OBJECT (table)) : NULL;
+	return to->cells[row][0]->heading
+		? html_utils_get_accessible (HTML_OBJECT (to->cells[row][0]), ATK_OBJECT (table)) : NULL;
 }
 
 /* unsupported calls
 
   AtkObject*
                     (* get_caption)              (AtkTable      *table);
-  G_CONST_RETURN gchar*
-                    (* get_column_description)   (AtkTable      *table,
+  const gchar *     (* get_column_description)   (AtkTable      *table,
                                                   gint          column);
-  G_CONST_RETURN gchar*
-                    (* get_row_description)      (AtkTable      *table,
+  const gchar *     (* get_row_description)      (AtkTable      *table,
                                                   gint          row);
   AtkObject*        (* get_summary)              (AtkTable      *table);
   void              (* set_caption)              (AtkTable      *table,
